summaryrefslogtreecommitdiffstats
path: root/llvm/include/llvm/IR/Instruction.h
diff options
context:
space:
mode:
Diffstat (limited to 'llvm/include/llvm/IR/Instruction.h')
-rw-r--r--llvm/include/llvm/IR/Instruction.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/llvm/include/llvm/IR/Instruction.h b/llvm/include/llvm/IR/Instruction.h
index 75f399ec2fcd..817abd6afbca 100644
--- a/llvm/include/llvm/IR/Instruction.h
+++ b/llvm/include/llvm/IR/Instruction.h
@@ -41,7 +41,7 @@ template <> struct ilist_alloc_traits<Instruction> {
static inline void deleteNode(Instruction *V);
};
-iterator_range<simple_ilist<DbgRecord>::iterator> getDbgValueRange(DPMarker *);
+iterator_range<simple_ilist<DbgRecord>::iterator> getDbgRecordRange(DPMarker *);
class Instruction : public User,
public ilist_node_with_parent<Instruction, BasicBlock,
@@ -79,29 +79,29 @@ public:
bool InsertAtHead = false);
/// Return a range over the DPValues attached to this instruction.
- iterator_range<simple_ilist<DbgRecord>::iterator> getDbgValueRange() const {
- return llvm::getDbgValueRange(DbgMarker);
+ iterator_range<simple_ilist<DbgRecord>::iterator> getDbgRecordRange() const {
+ return llvm::getDbgRecordRange(DbgMarker);
}
/// Return an iterator to the position of the "Next" DPValue after this
/// instruction, or std::nullopt. This is the position to pass to
/// BasicBlock::reinsertInstInDPValues when re-inserting an instruction.
std::optional<simple_ilist<DbgRecord>::iterator> getDbgReinsertionPosition();
/// Returns true if any DPValues are attached to this instruction.
- bool hasDbgValues() const;
+ bool hasDbgRecords() const;
/// Transfer any DPValues on the position \p It onto this instruction,
/// by simply adopting the sequence of DPValues (which is efficient) if
/// possible, by merging two sequences otherwise.
- void adoptDbgValues(BasicBlock *BB, InstListType::iterator It,
- bool InsertAtHead);
+ void adoptDbgRecords(BasicBlock *BB, InstListType::iterator It,
+ bool InsertAtHead);
/// Erase any DPValues attached to this instruction.
- void dropDbgValues();
+ void dropDbgRecords();
/// Erase a single DPValue \p I that is attached to this instruction.
- void dropOneDbgValue(DbgRecord *I);
+ void dropOneDbgRecord(DbgRecord *I);
/// Handle the debug-info implications of this instruction being removed. Any
/// attached DPValues need to "fall" down onto the next instruction.
@@ -79,29 +79,29 @@ public:
/// Return an iterator to the position of the "Next" DPValue after this
/// instruction, or std::nullopt. This is the position to pass to
- /// BasicBlock::reinsertInstInDPValues when re-inserting an instruction.
+ /// BasicBlock::reinsertInstInDbgRecords when re-inserting an instruction.
std::optional<simple_ilist<DbgRecord>::iterator> getDbgReinsertionPosition();
/// Returns true if any DPValues are attached to this instruction.